@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GHex; see the file COPYING.
-   If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   If not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Author: Jaka Mocnik <jaka@gnu.org>
 */
@@ -52,7 +52,7 @@ PropertyUI *prefs_ui = NULL;
 PropertyUI *
 create_prefs_dialog()
 {
-	GtkWidget *vbox, *label, *frame, *box, *fbox, *flabel, *table;
+	GtkWidget *vbox, *label, *frame, *box, *fbox, *flabel, *grid;
 	GtkAdjustment *undo_adj, *box_adj;
 	GtkWidget *notebook;
 
@@ -88,14 +88,14 @@ create_prefs_dialog()
 	gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(pui->pbox))), notebook);
 
 	/* editing page */
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(vbox);
 
 	/* max undo levels */
 	undo_adj = GTK_ADJUSTMENT(gtk_adjustment_new(MIN(max_undo_depth, MAX_MAX_UNDO_DEPTH),
 												 0, MAX_MAX_UNDO_DEPTH, 1, 10, 0));
 
-	box = gtk_hbox_new(FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show(box);
 
 	label = gtk_label_new_with_mnemonic(_("_Maximum number of undo levels:"));
@@ -110,7 +110,7 @@ create_prefs_dialog()
 	gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 8);
 
 	/* cursor offset format */
-	box = gtk_hbox_new(FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show(box);
 
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), pui->undo_spin);
@@ -173,7 +173,7 @@ create_prefs_dialog()
 	gtk_notebook_append_page (GTK_NOTEBOOK(notebook), vbox, label);
 
 	/* display page */
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(vbox);
 	
 	/* display font */
@@ -181,7 +181,7 @@ create_prefs_dialog()
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 	
-	fbox = gtk_hbox_new(0, 5);
+	fbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
 	pui->font_button = gtk_font_button_new();
 	gtk_font_button_set_font_name(GTK_FONT_BUTTON(pui->font_button),
 								  def_font_name);
@@ -204,7 +204,7 @@ create_prefs_dialog()
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 
-	box = gtk_vbox_new(FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(box);
 	group = NULL;
 	for(i = 0; i < 3; i++) {
@@ -221,7 +221,7 @@ create_prefs_dialog()
 	gtk_notebook_append_page (GTK_NOTEBOOK(notebook), vbox, label);
 	
 	/* printing page */
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(vbox);
 
 	/* paper selection */
@@ -234,14 +234,18 @@ create_prefs_dialog()
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 
-	table = gtk_table_new(2, 3, TRUE);
-	gtk_widget_show(table);
+	grid = gtk_grid_new ();
+	g_object_set (grid,
+	              "orientation", GTK_ORIENTATION_VERTICAL,
+	              "row-spacing", 6,
+	              "column-spacing", 12,
+	              NULL);
+	gtk_widget_show (grid);
+
 	label = gtk_label_new_with_mnemonic(_("_Data font:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-					 GTK_FILL, GTK_FILL,
-					 4, 4);
+	gtk_container_add (GTK_CONTAINER (grid), label);
 
 	pui->df_button = gtk_font_button_new_with_font(def_font_name);
 	g_signal_connect (G_OBJECT (pui->df_button), "font_set",
@@ -256,22 +260,15 @@ create_prefs_dialog()
 		add_atk_relation (pui->df_button, label, ATK_RELATION_LABELLED_BY);
 	}	
 	
+	gtk_widget_set_hexpand (pui->df_button, TRUE);
 	gtk_widget_show(pui->df_button);
-	gtk_table_attach(GTK_TABLE(table), pui->df_button, 1, 2, 0, 1,
-					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 4, 4);
-	label = gtk_label_new("");
-	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 0, 1,
-					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 4, 4);
+	gtk_grid_attach_next_to (GTK_GRID (grid), pui->df_button, label,
+	                         GTK_POS_RIGHT, 1, 1);
 
 	label = gtk_label_new_with_mnemonic(_("Header fo_nt:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
-					 GTK_FILL, GTK_FILL,
-					 4, 4);
+	gtk_container_add (GTK_CONTAINER (grid), label);
 	pui->hf_button = gtk_font_button_new_with_font(def_font_name);
 	g_signal_connect (G_OBJECT (pui->hf_button), "font_set",
 					  G_CALLBACK (select_font_cb), pui);
@@ -285,18 +282,17 @@ create_prefs_dialog()
 		add_atk_relation (pui->hf_button, label, ATK_RELATION_LABELLED_BY);
 	}
 
+	gtk_widget_set_hexpand (pui->hf_button, TRUE);
 	gtk_widget_show(pui->hf_button);
-	gtk_table_attach(GTK_TABLE(table), pui->hf_button, 1, 2, 1, 2,
-					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 4, 4);
+	gtk_grid_attach_next_to (GTK_GRID (grid), pui->hf_button, label,
+	                         GTK_POS_RIGHT, 1, 1);
 
 	label = gtk_label_new("");
+	gtk_widget_set_hexpand (label, TRUE);
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 1, 2,
-					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 4, 4);
+	gtk_grid_attach (GTK_GRID (grid), label, 2, 1, 1, 1);
 
-	gtk_container_add(GTK_CONTAINER(frame), table);
+	gtk_container_add (GTK_CONTAINER (frame), grid);
 
 	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE,
 					   4);
@@ -304,7 +300,7 @@ create_prefs_dialog()
 	/* shaded box entry */
 	box_adj = GTK_ADJUSTMENT(gtk_adjustment_new(0, 0, 1000, 1, 10, 0));
 
-	box = gtk_hbox_new(FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show(box);
 
 	label = gtk_label_new_with_mnemonic(_("_Print shaded box over:"));
@@ -391,10 +387,10 @@ max_undo_changed_cb(GtkAdjustment *adj, PropertyUI *pui)
 	if((guint)gtk_adjustment_get_value(adj) != max_undo_depth) {
 		max_undo_depth = gtk_spin_button_get_value_as_int
 			(GTK_SPIN_BUTTON(pui->undo_spin));
-		gconf_client_set_int (gconf_client,
-							  GHEX_BASE_KEY GHEX_PREF_MAX_UNDO_DEPTH,
-							  max_undo_depth,
-							  NULL);
+		g_settings_set (settings,
+		                GHEX_PREF_MAX_UNDO_DEPTH,
+		                "u",
+		                max_undo_depth);
 	}
 }
 
@@ -404,10 +400,10 @@ box_size_changed_cb(GtkAdjustment *adj, PropertyUI *pui)
 	if((guint)gtk_adjustment_get_value(adj) != shaded_box_size) {
 		shaded_box_size = gtk_spin_button_get_value_as_int
 			(GTK_SPIN_BUTTON(pui->box_size_spin));
-		gconf_client_set_int (gconf_client,
-							  GHEX_BASE_KEY GHEX_PREF_BOX_SIZE,
-							  shaded_box_size,
-							  NULL);
+		g_settings_set (settings,
+		                GHEX_PREF_BOX_SIZE,
+		                "u",
+		                shaded_box_size);
 	}
 }
 
@@ -416,10 +412,9 @@ offsets_col_cb(GtkToggleButton *tb, PropertyUI *pui)
 {
 	show_offsets_column = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON(pui->offsets_col));
-	gconf_client_set_bool (gconf_client,
-						   GHEX_BASE_KEY GHEX_PREF_OFFSETS_COLUMN,
-						   show_offsets_column,
-						   NULL);	
+	g_settings_set_boolean (settings,
+	                        GHEX_PREF_OFFSETS_COLUMN,
+	                        show_offsets_column);
 }
 
 static void
@@ -432,10 +427,9 @@ group_type_cb(GtkRadioButton *rd, PropertyUI *pui)
 			def_group_type = group_type[i];
 			break;
 		}
-	gconf_client_set_int (gconf_client,
-						  GHEX_BASE_KEY GHEX_PREF_GROUP,
-						  def_group_type,
-						  NULL);
+	g_settings_set_enum (settings,
+	                     GHEX_PREF_GROUP,
+	                     def_group_type);
 }
 
 static void
@@ -496,10 +490,9 @@ select_display_font_cb(GtkWidget *w, PropertyUI *pui)
 				(gtk_font_button_get_font_name
 				 (GTK_FONT_BUTTON(pui->font_button)));
 			def_font_desc = new_desc;
-			gconf_client_set_string (gconf_client,
-									 GHEX_BASE_KEY GHEX_PREF_FONT,
-									 def_font_name,
-									 NULL);
+			g_settings_set_string (settings,
+			                       GHEX_PREF_FONT,
+			                       def_font_name);
 		}
 		else
 			display_error_dialog (ghex_window_get_active(),
@@ -515,20 +508,18 @@ select_font_cb(GtkWidget *w, PropertyUI *pui)
 			g_free(data_font_name);
 		data_font_name = g_strdup(gtk_font_button_get_font_name
 								  (GTK_FONT_BUTTON (pui->df_button)));
-		gconf_client_set_string (gconf_client,
-								 GHEX_BASE_KEY GHEX_PREF_DATA_FONT,
-								 data_font_name,
-								 NULL);
+		g_settings_set_string (settings,
+		                       GHEX_PREF_DATA_FONT,
+		                       data_font_name);
 	}
 	else if(w == pui->hf_button) {
 		if(header_font_name)
 			g_free(header_font_name);
 		header_font_name = g_strdup(gtk_font_button_get_font_name
 									(GTK_FONT_BUTTON (pui->hf_button)));
-		gconf_client_set_string (gconf_client,
-								 GHEX_BASE_KEY GHEX_PREF_HEADER_FONT,
-								 header_font_name,
-								 NULL);
+		g_settings_set_string (settings,
+		                       GHEX_PREF_HEADER_FONT,
+		                       header_font_name);
 	}
 }
 
@@ -577,10 +568,9 @@ update_offset_fmt_from_entry(GtkEntry *entry, PropertyUI *pui)
 	}
 	if(offset_fmt != old_offset_fmt)
 		g_free(old_offset_fmt);
-	gconf_client_set_string (gconf_client,
-							 GHEX_BASE_KEY GHEX_PREF_OFFSET_FORMAT,
-							 offset_fmt,
-							 NULL);
+	g_settings_set_string (settings,
+	                       GHEX_PREF_OFFSET_FORMAT,
+	                       offset_fmt);
 	win_list = ghex_window_get_list();
 	while(NULL != win_list) {
 		ghex_window_update_status_message((GHexWindow *)win_list->data);
